#!/bin/bash

################################
# 作用：TE 备份脚本。将 usr 目录备份打包。
# 版本：1.0.3，2019-09-30
# 作者：www.typechodev.com modefid by uy_sun
# 用法：假如 typecho 安装在 /path_to/yoursite.com/，那么执行 "./backup_typecho.sh /path_to/yoursite.com" 即可开始备份。
# 备份结果放在 $HOME/backups/yoursite/ 目录下。
################################

backup_dir="$HOME/backups/"

function print_help(){
    echo 'Usage: $shell dir_to_typecho'
}

function die(){
    test -z "$1" || echo "$1"
    exit 1
}

if [ "$#" -lt "1" ]
then
    print_help
    exit 1
fi
te_dir="$1"
backup_dir="$backup_dir`basename "$te_dir"`"

#判断备份时间是否过频
min_time="43200" #12小时
flag="/tmp/last_backup_typecho_`echo $te_dir | md5sum | awk '{print $1}'`"
last_backup="0"
test -f $flag && last_backup="`ls -l --time-style=+%s "$flag" | awk '{print $6}'`"
delta_time=$(expr "`date +%s`" - "$last_backup")

test "$delta_time" -lt "$min_time" && die "Time from last backup is less then $min_time, skip this time"

#初始化变量
te_usr_dir="$te_dir/usr"

#初始化环境
test -d "$backup_dir" || mkdir -p "$backup_dir" || die "Can not create backup dir"

#备份 usr 目录
echo "Try to tar usr dir..."
tar_target="/tmp/user.tar.gz"
test -f "$tar_target" && rm "$tar_target"
cd "$te_usr_dir" && tar czf "$tar_target" --exclude=plugins *
echo "Tar done."

echo "Try to pack..."
md5sum "$tar_target" > "$tar_target.md5sum"
backup_file="$backup_dir/`basename "$te_dir"`.`date +%s`.tar.gz"
tar czvPf "$backup_file" "$tar_target" "$tar_target.md5sum"

#清理临时文件
rm $tar_target
rm "$tar_target.md5sum"

touch "$flag"
echo "Backup to $backup_file done."
